#pragma rtGlobals=1		// Use modern global access method.

#pragma version = 1.0

// ***************************
//	NI-DAQmx constant definitions for use with NIDAQmxBaseAccess.xop
//
// This procedure file defines constants that are used in NI-DAQmx Base functions. This makes it
// more convenient to use the DAQmxBaseXOP_ functions. This file was derived from the definitions
// in NIDAQmxBase.h header file that NI ships with NI-DAQmx Base.
//
// Some of the constant names as defined by NI are too long for Igor; these have been replaced
// with shortened names. Where this has been done, I have commented out the too-long name. The
// the replacement name follows it on the next line. If you use a documented constant and it is
// not defined or Igor complains that it is too long, search for it here to see if I have privided 
// a shortened version.
//
// NI also grouped the constants by their use in functions. This means that a number of the
// constants are duplicated, which causes an error in the Igor compiler. The duplicate definitions
// have been commented out.
//
// Many of these constants cannot be used with NI-DAQmx Base because they refer to properties
// that are not supported by NI-DAQmx Base.
//
// John Weeks, WaveMetrics, Inc.
//
// ***************************

// ******************************************************************************
// *** NI-DAQmx Values **********************************************************
// ******************************************************************************/

// ******************************************************/
// ***    Non-Attribute Function Parameter Values     ***/
// ******************************************************/

//*** Values for the Mode parameter of DAQmxTaskControl ***
constant DAQmx_Val_Task_Start =                                               0   // Start
constant DAQmx_Val_Task_Stop =                                                1   // Stop
constant DAQmx_Val_Task_Verify =                                              2   // Verify
constant DAQmx_Val_Task_Commit =                                              3   // Commit
constant DAQmx_Val_Task_Reserve =                                             4   // Reserve
constant DAQmx_Val_Task_Unreserve =                                           5   // Unreserve
constant DAQmx_Val_Task_Abort =                                               6   // Abort

//*** Values for the Action parameter of DAQmxControlWatchdogTask ***
constant DAQmx_Val_ResetTimer =                                               0   // Reset Timer
constant DAQmx_Val_ClearExpiration =                                          1   // Clear Expiration

//*** Values for the Line Grouping parameter of DAQmxCreateDIChan and DAQmxCreateDOChan ***
constant DAQmx_Val_ChanPerLine =                                              0   // One Channel For Each Line
constant DAQmx_Val_ChanForAllLines =                                          1   // One Channel For All Lines

//*** Values for the Fill Mode parameter of DAQmxReadAnalogF64, DAQmxReadBinaryI16, DAQmxReadBinaryU16, DAQmxReadDigitalU8, DAQmxReadDigitalU32, DAQmxReadDigitalLines ***
//*** Values for the Data Layout parameter of DAQmxWriteAnalogF64, DAQmxWriteBinaryI16, DAQmxWriteDigitalU8, DAQmxWriteDigitalU32, DAQmxWriteDigitalLines ***
constant DAQmx_Val_GroupByChannel =                                           0   // Group by Channel
constant DAQmx_Val_GroupByScanNumber =                                        1   // Group by Scan Number

//*** Values for the Signal Modifiers parameter of DAQmxConnectTerms ***/
constant DAQmx_Val_DoNotInvertPolarity =                                      0   // Do not invert polarity
constant DAQmx_Val_InvertPolarity =                                           1   // Invert polarity

//*** Values for the Action paramter of DAQmxCloseExtCal ***
constant DAQmx_Val_Action_Commit =                                            0   // Commit
constant DAQmx_Val_Action_Cancel =                                            1   // Cancel

//*** Values for the Trigger ID parameter of DAQmxSendSoftwareTrigger ***
constant DAQmx_Val_AdvanceTrigger =                                           12488 // Advance Trigger

//*** Value set for the Signal ID parameter of DAQmxExportSignal ***
constant DAQmx_Val_AIConvertClock =                                           12484 // AI Convert Clock
constant DAQmx_Val_20MHzTimebaseClock =                                       12486 // 20MHz Timebase Clock
constant DAQmx_Val_SampleClock =                                              12487 // Sample Clock
//constant DAQmx_Val_AdvanceTrigger =                                           12488 // Advance Trigger
constant DAQmx_Val_ReferenceTrigger =                                         12490 // Reference Trigger
constant DAQmx_Val_StartTrigger =                                             12491 // Start Trigger
constant DAQmx_Val_AdvCmpltEvent =                                            12492 // Advance Complete Event
constant DAQmx_Val_AIHoldCmpltEvent =                                         12493 // AI Hold Complete Event
constant DAQmx_Val_CounterOutputEvent =                                       12494 // Counter Output Event
constant DAQmx_Val_ChangeDetectionEvent =                                     12511 // Change Detection Event
constant DAQmx_Val_WDTExpiredEvent =                                          12512 // Watchdog Timer Expired Event

//*** Value set for the ActiveEdge parameter of DAQmxCfgSampClkTiming ***
constant DAQmx_Val_Rising =                                                   10280 // Rising
constant DAQmx_Val_Falling =                                                  10171 // Falling

//*** Value set SwitchPathType ***
//*** Value set for the output Path Status parameter of DAQmxSwitchFindPath ***
constant DAQmx_Val_PathStatus_Available =                                     10431 // Path Available
//constant DAQmx_Val_PathStatus_AlreadyExists =                                 10432 // Path Already Exists
constant DAQmx_Val_PathStatus_Exists =                                        10432 // Path Already Exists
//constant DAQmx_Val_PathStatus_Unsupported =                                   10433 // Path Unsupported
constant DAQmx_Val_PathStatus_Unsprted =                                      10433 // Path Unsupported
//constant DAQmx_Val_PathStatus_ChannelInUse =                                  10434 // Channel In Use
constant DAQmx_Val_PathStatus_ChanInUse =                                     10434 // Channel In Use
//constant DAQmx_Val_PathStatus_SourceChannelConflict =                         10435 // Channel Source Conflict
constant DAQmx_Val_PathStatus_SrcCCnflct =                                    10435 // Channel Source Conflict
//constant DAQmx_Val_PathStatus_ChannelReservedForRouting =                     10436 // Channel Reserved for Routing
constant DAQmx_Val_PathStatus_CReserved =                                     10436 // Channel Reserved for Routing

//*** Value set for the Units parameter of DAQmxCreateAIThrmcplChan, DAQmxCreateAIRTDChan, DAQmxCreateAIThrmstrChanIex, DAQmxCreateAIThrmstrChanVex and DAQmxCreateAITempBuiltInSensorChan ***
constant DAQmx_Val_DegC =                                                     10143 // Deg C
constant DAQmx_Val_DegF =                                                     10144 // Deg F
constant DAQmx_Val_Kelvins =                                                  10325 // Kelvins
constant DAQmx_Val_DegR =                                                     10145 // Deg R

//*** Value set for the state parameter of DAQmxSetDigitalPowerUpStates ***
constant DAQmx_Val_High =                                                     10192 // High
constant DAQmx_Val_Low =                                                      10214 // Low
constant DAQmx_Val_Tristate =                                                 10310 // Tristate

//*** Value set RelayPos ***
//*** Value set for the state parameter of DAQmxSwitchGetSingleRelayPos and DAQmxSwitchGetMultiRelayPos ***
constant DAQmx_Val_Open =                                                     10437 // Open
constant DAQmx_Val_Closed =                                                   10438 // Closed

//*** Value for the Terminal Config parameter of DAQmxCreateAIVoltageChan, DAQmxCreateAICurrentChan and DAQmxCreateAIVoltageChanWithExcit ***
constant DAQmx_Val_Cfg_Default =                                              -1 // Default

//*** Value for the Timeout parameter of DAQmxWaitUntilTaskDone
constant DAQmx_Val_WaitInfinitely =                                           -1.0

//*** Value for the Number of Samples per Channel parameter of DAQmxReadAnalogF64, DAQmxReadBinaryI16, DAQmxReadBinaryU16, DAQmxReadDigitalU8, DAQmxReadDigitalU32,
//    DAQmxReadDigitalLines, DAQmxReadCounterF64, DAQmxReadCounterU32 and DAQmxReadRaw ***
constant DAQmx_Val_Auto =                                                     -1

//******************************************************/
//***              Attribute Values                  ***/
//******************************************************/

//*** Values for DAQmx_AI_ACExcit_WireMode ***
//*** Value set ACExcitWireMode ***
constant DAQmx_Val_4Wire =                                                        4 // 4-Wire
constant DAQmx_Val_5Wire =                                                        5 // 5-Wire

//*** Values for DAQmx_AI_MeasType ***
//*** Value set AIMeasurementType ***
constant DAQmx_Val_Voltage =                                                  10322 // Voltage
constant DAQmx_Val_Current =                                                  10134 // Current
//constant DAQmx_Val_Voltage_CustomWithExcitation =                             10323 // More:Voltage:Custom with Excitation
constant DAQmx_Val_Voltage_CustomWithExc =                                    10323 // More:Voltage:Custom with Excitation
constant DAQmx_Val_Freq_Voltage =                                             10181 // Frequency
constant DAQmx_Val_Resistance =                                               10278 // Resistance
constant DAQmx_Val_Temp_TC =                                                  10303 // Temperature:Thermocouple
constant DAQmx_Val_Temp_Thrmstr =                                             10302 // Temperature:Thermistor
constant DAQmx_Val_Temp_RTD =                                                 10301 // Temperature:RTD
constant DAQmx_Val_Temp_BuiltInSensor =                                       10311 // Temperature:Built-in Sensor
constant DAQmx_Val_Strain_Gage =                                              10300 // Strain Gage
constant DAQmx_Val_Position_LVDT =                                            10352 // Position:LVDT
constant DAQmx_Val_Position_RVDT =                                            10353 // Position:RVDT
constant DAQmx_Val_Accelerometer =                                            10356 // Accelerometer

//*** Values for DAQmx_AO_OutputType ***
//*** Value set AOOutputChannelType ***
//constant DAQmx_Val_Voltage =                                                  10322 // Voltage
//constant DAQmx_Val_Current =                                                  10134 // Current

//*** Values for DAQmx_AI_Accel_SensitivityUnits ***
//*** Value set AccelSensitivityUnits1 ***
constant DAQmx_Val_mVoltsPerG =                                               12509 // mVolts/g
constant DAQmx_Val_VoltsPerG =                                                12510 // Volts/g

//*** Values for DAQmx_AI_Accel_Units ***
//*** Value set AccelUnits2 ***
constant DAQmx_Val_AccelUnit_g =                                              10186 // g
constant DAQmx_Val_FromCustomScale =                                          10065 // From Custom Scale

//*** Values for DAQmx_SampQuant_SampMode ***
//*** Value set AcquisitionType ***
constant DAQmx_Val_FiniteSamps =                                              10178 // Finite Samples
constant DAQmx_Val_ContSamps =                                                10123 // Continuous Samples

//*** Values for DAQmx_AnlgLvl_PauseTrig_When ***
//*** Value set ActiveLevel ***
constant DAQmx_Val_AboveLvl =                                                 10093 // Above Level
constant DAQmx_Val_BelowLvl =                                                 10107 // Below Level

//*** Values for DAQmx_AI_RVDT_Units ***
//*** Value set AngleUnits1 ***
constant DAQmx_Val_Degrees =                                                  10146 // Degrees
constant DAQmx_Val_Radians =                                                  10273 // Radians
//constant DAQmx_Val_FromCustomScale =                                          10065 // From Custom Scale

//*** Values for DAQmx_CI_AngEncoder_Units ***
//*** Value set AngleUnits2 ***
//constant DAQmx_Val_Degrees =                                                  10146 // Degrees
//constant DAQmx_Val_Radians =                                                  10273 // Radians
constant DAQmx_Val_Ticks =                                                    10304 // Ticks
//constant DAQmx_Val_FromCustomScale =                                          10065 // From Custom Scale

//*** Values for DAQmx_AI_AutoZeroMode ***
//*** Value set AutoZeroType1 ***
constant DAQmx_Val_None =                                                     10230 // None
constant DAQmx_Val_Once =                                                     10244 // Once

//*** Values for DAQmx_SwitchScan_BreakMode ***
//*** Value set BreakMode ***
constant DAQmx_Val_NoAction =                                                 10227 // No Action
constant DAQmx_Val_BreakBeforeMake =                                          10110 // Break Before Make

//*** Values for DAQmx_AI_Bridge_Cfg ***
//*** Value set BridgeConfiguration1 ***
constant DAQmx_Val_FullBridge =                                               10182 // Full Bridge
constant DAQmx_Val_HalfBridge =                                               10187 // Half Bridge
constant DAQmx_Val_QuarterBridge =                                            10270 // Quarter Bridge
constant DAQmx_Val_NoBridge =                                                 10228 // No Bridge

//*** Values for DAQmx_CI_MeasType ***
//*** Value set CIMeasurementType ***
constant DAQmx_Val_CountEdges =                                               10125 // Count Edges
constant DAQmx_Val_Freq =                                                     10179 // Frequency
constant DAQmx_Val_Period =                                                   10256 // Period
constant DAQmx_Val_PulseWidth =                                               10359 // Pulse Width
constant DAQmx_Val_SemiPeriod =                                               10289 // Semi Period
constant DAQmx_Val_Position_AngEncoder =                                      10360 // Position:Angular Encoder
constant DAQmx_Val_Position_LinEncoder =                                      10361 // Position:Linear Encoder
constant DAQmx_Val_TwoEdgeSep =                                               10267 // Two Edge Separation

//*** Values for DAQmx_AI_Thrmcpl_CJCSrc ***
//*** Value set CJCSource1 ***
constant DAQmx_Val_BuiltIn =                                                  10200 // Built-In
constant DAQmx_Val_ConstVal =                                                 10116 // Constant Value
constant DAQmx_Val_Chan =                                                     10113 // Channel

//*** Values for DAQmx_CO_OutputType ***
//*** Value set COOutputType ***
constant DAQmx_Val_Pulse_Time =                                               10269 // Pulse:Time
constant DAQmx_Val_Pulse_Freq =                                               10119 // Pulse:Frequency
constant DAQmx_Val_Pulse_Ticks =                                              10268 // Pulse:Ticks

//*** Values for DAQmx_ChanType ***
//*** Value set ChannelType ***
constant DAQmx_Val_AI =                                                       10100 // Analog Input
constant DAQmx_Val_AO =                                                       10102 // Analog Output
constant DAQmx_Val_DI =                                                       10151 // Digital Input
constant DAQmx_Val_DO =                                                       10153 // Digital Output
constant DAQmx_Val_CI =                                                       10131 // Counter Input
constant DAQmx_Val_CO =                                                       10132 // Counter Output

//*** Values for DAQmx_CI_CountEdges_Dir ***
//*** Value set CountDirection1 ***
constant DAQmx_Val_CountUp =                                                  10128 // Count Up
constant DAQmx_Val_CountDown =                                                10124 // Count Down
constant DAQmx_Val_ExtControlled =                                            10326 // Externally Controlled

//*** Values for DAQmx_CI_Freq_MeasMeth ***
//*** Values for DAQmx_CI_Period_MeasMeth ***
//*** Value set CounterFrequencyMethod ***
constant DAQmx_Val_LowFreq1Ctr =                                              10105 // Low Frequency with 1 Counter
constant DAQmx_Val_HighFreq2Ctr =                                             10157 // High Frequency with 2 Counters
constant DAQmx_Val_LargeRng2Ctr =                                             10205 // Large Range with 2 Counters

//*** Values for DAQmx_AI_Coupling ***
//*** Value set Coupling1 ***
constant DAQmx_Val_AC =                                                       10045 // AC
constant DAQmx_Val_DC =                                                       10050 // DC
constant DAQmx_Val_GND =                                                      10066 // GND

//*** Values for DAQmx_AI_CurrentShunt_Loc ***
//*** Value set CurrentShuntResistorLocation1 ***
constant DAQmx_Val_Internal =                                                 10200 // Internal
constant DAQmx_Val_External =                                                 10167 // External

//*** Values for DAQmx_AI_Current_Units ***
//*** Values for DAQmx_AO_Current_Units ***
//*** Value set CurrentUnits1 ***
constant DAQmx_Val_Amps =                                                     10342 // Amps
//constant DAQmx_Val_FromCustomScale =                                          10065 // From Custom Scale

//*** Values for DAQmx_AI_DataXferMech ***
//*** Values for DAQmx_AO_DataXferMech ***
//*** Values for DAQmx_CI_DataXferMech ***
//*** Value set DataTransferMechanism ***
constant DAQmx_Val_DMA =                                                      10054 // DMA
constant DAQmx_Val_Interrupts =                                               10204 // Interrupts
constant DAQmx_Val_ProgrammedIO =                                             10264 // Programmed I/O

//*** Values for DAQmx_Watchdog_DO_ExpirState ***
//*** Value set DigitalLineState ***
//constant DAQmx_Val_High =                                                     10192 // High
//constant DAQmx_Val_Low =                                                      10214 // Low
//constant DAQmx_Val_Tristate =                                                 10310 // Tristate
constant DAQmx_Val_NoChange =                                                 10160 // No Change

//*** Values for DAQmx_StartTrig_DelayUnits ***
//*** Value set DigitalWidthUnits1 ***
constant DAQmx_Val_SampClkPeriods =                                           10286 // Sample Clock Periods
constant DAQmx_Val_Seconds =                                                  10364 // Seconds
//constant DAQmx_Val_Ticks =                                                    10304 // Ticks

//*** Values for DAQmx_DelayFromSampClk_DelayUnits ***
//*** Value set DigitalWidthUnits2 ***
//constant DAQmx_Val_Seconds =                                                  10364 // Seconds
//constant DAQmx_Val_Ticks =                                                    10304 // Ticks

//*** Values for DAQmx_Exported_AdvTrig_Pulse_WidthUnits ***
//*** Value set DigitalWidthUnits3 ***
//constant DAQmx_Val_Seconds =                                                  10364 // Seconds

//*** Values for DAQmx_CI_Freq_StartingEdge ***
//*** Values for DAQmx_CI_Period_StartingEdge ***
//*** Values for DAQmx_CI_CountEdges_ActiveEdge ***
//*** Values for DAQmx_CI_PulseWidth_StartingEdge ***
//*** Values for DAQmx_CI_TwoEdgeSep_FirstEdge ***
//*** Values for DAQmx_CI_TwoEdgeSep_SecondEdge ***
//*** Values for DAQmx_CI_CtrTimebaseActiveEdge ***
//*** Values for DAQmx_CO_CtrTimebaseActiveEdge ***
//*** Values for DAQmx_SampClk_ActiveEdge ***
//*** Values for DAQmx_SampClk_Timebase_ActiveEdge ***
//*** Values for DAQmx_AIConv_ActiveEdge ***
//*** Values for DAQmx_DigEdge_StartTrig_Edge ***
//*** Values for DAQmx_DigEdge_RefTrig_Edge ***
//*** Values for DAQmx_DigEdge_AdvTrig_Edge ***
//*** Values for DAQmx_DigEdge_ArmStartTrig_Edge ***
//*** Values for DAQmx_DigEdge_WatchdogExpirTrig_Edge ***
//*** Value set Edge1 ***
//constant DAQmx_Val_Rising =                                                   10280 // Rising
//constant DAQmx_Val_Falling =                                                  10171 // Falling

//*** Values for DAQmx_CI_Encoder_DecodingType ***
//*** Value set EncoderType2 ***
constant DAQmx_Val_X1 =                                                       10090 // X1
constant DAQmx_Val_X2 =                                                       10091 // X2
constant DAQmx_Val_X4 =                                                       10092 // X4
constant DAQmx_Val_TwoPulseCounting =                                         10313 // Two Pulse Counting

//*** Values for DAQmx_CI_Encoder_ZIndexPhase ***
//*** Value set EncoderZIndexPhase1 ***
constant DAQmx_Val_AHighBHigh =                                               10040 // A High B High
constant DAQmx_Val_AHighBLow =                                                10041 // A High B Low
constant DAQmx_Val_ALowBHigh =                                                10042 // A Low B High
constant DAQmx_Val_ALowBLow =                                                 10043 // A Low B Low

//*** Values for DAQmx_AI_Excit_DCorAC ***
//*** Value set ExcitationDCorAC ***
//constant DAQmx_Val_DC =                                                       10050 // DC
//constant DAQmx_Val_AC =                                                       10045 // AC

//*** Values for DAQmx_AI_Excit_Src ***
//*** Value set ExcitationSource ***
//constant DAQmx_Val_Internal =                                                 10200 // Internal
//constant DAQmx_Val_External =                                                 10167 // External
//constant DAQmx_Val_None =                                                     10230 // None

//*** Values for DAQmx_AI_Excit_VoltageOrCurrent ***
//*** Value set ExcitationVoltageOrCurrent ***
//constant DAQmx_Val_Voltage =                                                  10322 // Voltage
//constant DAQmx_Val_Current =                                                  10134 // Current

//*** Values for DAQmx_Exported_CtrOutEvent_OutputBehavior ***
//*** Value set ExportActions2 ***
constant DAQmx_Val_Pulse =                                                    10265 // Pulse
constant DAQmx_Val_Toggle =                                                   10307 // Toggle

//*** Values for DAQmx_Exported_SampClk_OutputBehavior ***
//*** Value set ExportActions3 ***
//constant DAQmx_Val_Pulse =                                                    10265 // Pulse
constant DAQmx_Val_Lvl =                                                      10210 // Level

//*** Values for DAQmx_AI_Freq_Units ***
//*** Value set FrequencyUnits ***
constant DAQmx_Val_Hz =                                                       10373 // Hz
//constant DAQmx_Val_FromCustomScale =                                          10065 // From Custom Scale

//*** Values for DAQmx_CO_Pulse_Freq_Units ***
//*** Value set FrequencyUnits2 ***
//constant DAQmx_Val_Hz =                                                       10373 // Hz

//*** Values for DAQmx_CI_Freq_Units ***
//*** Value set FrequencyUnits3 ***
//constant DAQmx_Val_Hz =                                                       10373 // Hz
//constant DAQmx_Val_Ticks =                                                    10304 // Ticks
//constant DAQmx_Val_FromCustomScale =                                          10065 // From Custom Scale


//*** Values for DAQmx_AI_DataXferReqCond ***
//*** Value set InputDataTransferCondition ***
//constant DAQmx_Val_OnBrdMemMoreThanHalfFull =                                 10237 // On Board Memory More than Half Full
constant DAQmx_Val_BrdMemMorThanHalfFull =                                    10237 // On Board Memory More than Half Full
constant DAQmx_Val_OnBrdMemNotEmpty =                                         10241 // On Board Memory Not Empty

//*** Values for DAQmx_AI_TermCfg ***
//*** Value set InputTermCfg ***
constant DAQmx_Val_RSE =                                                      10083 // RSE
constant DAQmx_Val_NRSE =                                                     10078 // NRSE
constant DAQmx_Val_Diff =                                                     10106 // Differential

//*** Values for DAQmx_AI_LVDT_SensitivityUnits ***
//*** Value set LVDTSensitivityUnits1 ***
//constant DAQmx_Val_mVoltsPerVoltPerMillimeter =                               12506 // mVolts/Volt/mMeter
constant DAQmx_Val_mVoltsPerVoltPer_mm =                                      12506 // mVolts/Volt/mMeter
//constant DAQmx_Val_mVoltsPerVoltPerMilliInch =                                12505 // mVolts/Volt/0.001 Inch
constant DAQmx_Val_mVoltsPerVoltPer_mIn =                                     12505 // mVolts/Volt/0.001 Inch

//*** Values for DAQmx_AI_LVDT_Units ***
//*** Value set LengthUnits2 ***
constant DAQmx_Val_Meters =                                                   10219 // Meters
constant DAQmx_Val_Inches =                                                   10379 // Inches
//constant DAQmx_Val_FromCustomScale =                                          10065 // From Custom Scale

//*** Values for DAQmx_CI_LinEncoder_Units ***
//*** Value set LengthUnits3 ***
//constant DAQmx_Val_Meters =                                                   10219 // Meters
//constant DAQmx_Val_Inches =                                                   10379 // Inches
//constant DAQmx_Val_Ticks =                                                    10304 // Ticks
//constant DAQmx_Val_FromCustomScale =                                          10065 // From Custom Scale

//*** Values for DAQmx_CI_OutputState ***
//*** Values for DAQmx_CO_Pulse_IdleState ***
//*** Values for DAQmx_CO_OutputState ***
//*** Values for DAQmx_Exported_CtrOutEvent_Toggle_IdleState ***
//*** Values for DAQmx_DigLvl_PauseTrig_When ***
//*** Value set Level1 ***
//constant DAQmx_Val_High =                                                     10192 // High
//constant DAQmx_Val_Low =                                                      10214 // Low

//*** Values for DAQmx_AIConv_Timebase_Src ***
//*** Value set MIOAIConvertTbSrc ***
constant DAQmx_Val_SameAsSampTimebase =                                       10284 // Same as Sample Timebase
constant DAQmx_Val_SameAsMasterTimebase =                                     10282 // Same as Master Timebase

//*** Values for DAQmx_AO_DataXferReqCond ***
//*** Value set OutputDataTransferCondition ***
constant DAQmx_Val_OnBrdMemEmpty =                                            10235 // On Board Memory Empty
//constant DAQmx_Val_OnBrdMemHalfFullOrLess =                                   10239 // On Board Memory Half Full or Less
constant DAQmx_Val_BrdMemHalfFullOrLess =                                     10239 // On Board Memory Half Full or Less
constant DAQmx_Val_OnBrdMemNotFull =                                          10242 // On Board Memory Less than Full

//*** Values for DAQmx_Read_OverWrite ***
//*** Value set OverwriteMode1 ***
constant DAQmx_Val_OverwriteUnreadSamps =                                     10252 // Overwrite Unread Samples
//constant DAQmx_Val_DoNotOverwriteUnreadSamps =                                10159 // Do Not Overwrite Unread Samples
constant DAQmx_Val_DoNotOvrwrtUnreadSamp =                                    10159 // Do Not Overwrite Unread Samples

//*** Values for DAQmx_Exported_AIConvClk_Pulse_Polarity ***
//*** Values for DAQmx_Exported_AdvTrig_Pulse_Polarity ***
//*** Values for DAQmx_Exported_AdvCmpltEvent_Pulse_Polarity ***
//*** Values for DAQmx_Exported_AIHoldCmpltEvent_PulsePolarity ***
//*** Values for DAQmx_Exported_CtrOutEvent_Pulse_Polarity ***
//*** Value set Polarity2 ***
constant DAQmx_Val_ActiveHigh =                                               10095 // Active High
constant DAQmx_Val_ActiveLow =                                                10096 // Active Low

//*** Values for DAQmx_AI_RTD_Type ***
//*** Value set RTDType1 ***
constant DAQmx_Val_Pt3750 =                                                   12481 // Pt3750
constant DAQmx_Val_Pt3851 =                                                   10071 // Pt3851
constant DAQmx_Val_Pt3911 =                                                   12482 // Pt3911
constant DAQmx_Val_Pt3916 =                                                   10069 // Pt3916
constant DAQmx_Val_Pt3920 =                                                   10053 // Pt3920
constant DAQmx_Val_Pt3928 =                                                   12483 // Pt3928
constant DAQmx_Val_Custom =                                                   10137 // Custom

//*** Values for DAQmx_AI_RVDT_SensitivityUnits ***
//*** Value set RVDTSensitivityUnits1 ***
//constant DAQmx_Val_mVoltsPerVoltPerDegree =                                   12507 // mVolts/Volt/Degree
constant DAQmx_Val_mVoltsPerVoltPerDeg =                                      12507 // mVolts/Volt/Degree
//constant DAQmx_Val_mVoltsPerVoltPerRadian =                                   12508 // mVolts/Volt/Radian
constant DAQmx_Val_mVoltsPerVoltPerRad =                                      12508 // mVolts/Volt/Radian

//*** Values for DAQmx_Read_RelativeTo ***
//*** Value set ReadRelativeTo ***
constant DAQmx_Val_FirstSample =                                              10424 // First Sample
constant DAQmx_Val_CurrReadPos =                                              10425 // Current Read Position
constant DAQmx_Val_RefTrig =                                                  10426 // Reference Trigger
constant DAQmx_Val_FirstPretrigSamp =                                         10427 // First Pretrigger Sample
constant DAQmx_Val_MostRecentSamp =                                           10428 // Most Recent Sample


//*** Values for DAQmx_Write_RegenMode ***
//*** Value set RegenerationMode1 ***
constant DAQmx_Val_AllowRegen =                                               10097 // Allow Regeneration
constant DAQmx_Val_DoNotAllowRegen =                                          10158 // Do Not Allow Regeneration

//*** Values for DAQmx_AI_ResistanceCfg ***
//*** Value set ResistanceConfiguration ***
constant DAQmx_Val_2Wire =                                                        2 // 2-Wire
constant DAQmx_Val_3Wire =                                                        3 // 3-Wire
//constant DAQmx_Val_4Wire =                                                        4 // 4-Wire

//*** Values for DAQmx_AI_Resistance_Units ***
//*** Value set ResistanceUnits1 ***
constant DAQmx_Val_Ohms =                                                     10384 // Ohms
//constant DAQmx_Val_FromCustomScale =                                          10065 // From Custom Scale

//*** Values for DAQmx_AI_ResolutionUnits ***
//*** Values for DAQmx_AO_ResolutionUnits ***
//*** Value set ResolutionType1 ***
constant DAQmx_Val_Bits =                                                     10109 // Bits

//*** Values for DAQmx_SampTimingType ***
//*** Value set SampleTimingType ***
constant DAQmx_Val_SampClk =                                                  10388 // Sample Clock
constant DAQmx_Val_Handshake =                                                10389 // Handshake
constant DAQmx_Val_Implicit =                                                 10451 // Implicit
constant DAQmx_Val_OnDemand =                                                 10390 // On Demand
constant DAQmx_Val_ChangeDetection =                                          12504 // Change Detection

//*** Values for DAQmx_Scale_Type ***
//*** Value set ScaleType ***
constant DAQmx_Val_Linear =                                                   10447 // Linear
constant DAQmx_Val_MapRanges =                                                10448 // Map Ranges
constant DAQmx_Val_Polynomial =                                               10449 // Polynomial
constant DAQmx_Val_Table =                                                    10450 // Table

//*** Values for DAQmx_AI_Bridge_ShuntCal_Select ***
//*** Value set ShuntCalSelect ***
constant DAQmx_Val_A =                                                        12513 // A
constant DAQmx_Val_B =                                                        12514 // B
constant DAQmx_Val_AandB =                                                    12515 // A and B

//*** Values for DAQmx_AnlgEdge_StartTrig_Slope ***
//*** Values for DAQmx_AnlgEdge_RefTrig_Slope ***
//*** Value set Slope1 ***
constant DAQmx_Val_RisingSlope =                                              10280 // Rising
constant DAQmx_Val_FallingSlope =                                             10171 // Falling

//*** Values for DAQmx_AI_Lowpass_SwitchCap_ClkSrc ***
//*** Values for DAQmx_AO_DAC_Ref_Src ***
//*** Value set SourceSelection ***
//constant DAQmx_Val_Internal =                                                 10200 // Internal
//constant DAQmx_Val_External =                                                 10167 // External

//*** Values for DAQmx_AI_StrainGage_Cfg ***
//*** Value set StrainGageBridgeType1 ***
constant DAQmx_Val_FullBridgeI =                                              10183 // Full Bridge I
constant DAQmx_Val_FullBridgeII =                                             10184 // Full Bridge II
constant DAQmx_Val_FullBridgeIII =                                            10185 // Full Bridge III
constant DAQmx_Val_HalfBridgeI =                                              10188 // Half Bridge I
constant DAQmx_Val_HalfBridgeII =                                             10189 // Half Bridge II
constant DAQmx_Val_QuarterBridgeI =                                           10271 // Quarter Bridge I
constant DAQmx_Val_QuarterBridgeII =                                          10272 // Quarter Bridge II

//*** Values for DAQmx_AI_Strain_Units ***
//*** Value set StrainUnits1 ***
constant DAQmx_Val_Strain =                                                   10299 // Strain
//constant DAQmx_Val_FromCustomScale =                                          10065 // From Custom Scale

//*** Values for DAQmx_SwitchScan_RepeatMode ***
//*** Value set SwitchScanRepeatMode ***
constant DAQmx_Val_Finite =                                                   10172 // Finite
constant DAQmx_Val_Cont =                                                     10117 // Continuous

//*** Values for DAQmx_SwitchChan_Usage ***
//*** Value set SwitchUsageTypes ***
constant DAQmx_Val_Source =                                                   10439 // Source
constant DAQmx_Val_Load =                                                     10440 // Load
constant DAQmx_Val_ReservedForRouting =                                       10441 // Reserved for Routing

//*** Values for DAQmx_AI_Temp_Units ***
//*** Value set TemperatureUnits1 ***
//constant DAQmx_Val_DegC =                                                     10143 // Deg C
//constant DAQmx_Val_DegF =                                                     10144 // Deg F
//constant DAQmx_Val_Kelvins =                                                  10325 // Kelvins
//constant DAQmx_Val_DegR =                                                     10145 // Deg R
//constant DAQmx_Val_FromCustomScale =                                          10065 // From Custom Scale

//*** Values for DAQmx_AI_Thrmcpl_Type ***
//*** Value set ThermocoupleType1 ***
constant DAQmx_Val_J_Type_TC =                                                10072 // J
constant DAQmx_Val_K_Type_TC =                                                10073 // K
constant DAQmx_Val_N_Type_TC =                                                10077 // N
constant DAQmx_Val_R_Type_TC =                                                10082 // R
constant DAQmx_Val_S_Type_TC =                                                10085 // S
constant DAQmx_Val_T_Type_TC =                                                10086 // T
constant DAQmx_Val_B_Type_TC =                                                10047 // B
constant DAQmx_Val_E_Type_TC =                                                10055 // E

//*** Values for DAQmx_CO_Pulse_Time_Units ***
//*** Value set TimeUnits2 ***
//constant DAQmx_Val_Seconds =                                                  10364 // Seconds

//*** Values for DAQmx_CI_Period_Units ***
//*** Values for DAQmx_CI_PulseWidth_Units ***
//*** Values for DAQmx_CI_TwoEdgeSep_Units ***
//*** Values for DAQmx_CI_SemiPeriod_Units ***
//*** Value set TimeUnits3 ***
//constant DAQmx_Val_Seconds =                                                  10364 // Seconds
//constant DAQmx_Val_Ticks =                                                    10304 // Ticks
//constant DAQmx_Val_FromCustomScale =                                          10065 // From Custom Scale

//*** Values for DAQmx_RefTrig_Type ***
//*** Value set TriggerType1 ***
constant DAQmx_Val_AnlgEdge =                                                 10099 // Analog Edge
constant DAQmx_Val_DigEdge =                                                  10150 // Digital Edge
constant DAQmx_Val_AnlgWin =                                                  10103 // Analog Window
//constant DAQmx_Val_None =                                                     10230 // None

//*** Values for DAQmx_ArmStartTrig_Type ***
//*** Values for DAQmx_WatchdogExpirTrig_Type ***
//*** Value set TriggerType4 ***
//constant DAQmx_Val_DigEdge =                                                  10150 // Digital Edge
//constant DAQmx_Val_None =                                                     10230 // None

//*** Values for DAQmx_AdvTrig_Type ***
//*** Value set TriggerType5 ***
//constant DAQmx_Val_DigEdge =                                                  10150 // Digital Edge
constant DAQmx_Val_Software =                                                 10292 // Software
//constant DAQmx_Val_None =                                                     10230 // None

//*** Values for DAQmx_PauseTrig_Type ***
//*** Value set TriggerType6 ***
constant DAQmx_Val_AnlgLvl =                                                  10101 // Analog Level
//constant DAQmx_Val_AnlgWin =                                                  10103 // Analog Window
constant DAQmx_Val_DigLvl =                                                   10152 // Digital Level
//constant DAQmx_Val_None =                                                     10230 // None

//*** Values for DAQmx_StartTrig_Type ***
//*** Value set TriggerType8 ***
//constant DAQmx_Val_AnlgEdge =                                                 10099 // Analog Edge
//constant DAQmx_Val_DigEdge =                                                  10150 // Digital Edge
//constant DAQmx_Val_AnlgWin =                                                  10103 // Analog Window
//constant DAQmx_Val_None =                                                     10230 // None

//*** Values for DAQmx_Scale_PreScaledUnits ***
//*** Value set UnitsPreScaled ***
constant DAQmx_Val_Volts =                                                    10348 // Volts
//constant DAQmx_Val_Amps =                                                     10342 // Amps
//constant DAQmx_Val_DegF =                                                     10144 // Deg F
//constant DAQmx_Val_DegC =                                                     10143 // Deg C
//constant DAQmx_Val_DegR =                                                     10145 // Deg R
//constant DAQmx_Val_Kelvins =                                                  10325 // Kelvins
//constant DAQmx_Val_Strain =                                                   10299 // Strain
//constant DAQmx_Val_Ohms =                                                     10384 // Ohms
//constant DAQmx_Val_Hz =                                                       10373 // Hz
//constant DAQmx_Val_Seconds =                                                  10364 // Seconds
//constant DAQmx_Val_Meters =                                                   10219 // Meters
//constant DAQmx_Val_Inches =                                                   10379 // Inches
//constant DAQmx_Val_Degrees =                                                  10146 // Degrees
//constant DAQmx_Val_Radians =                                                  10273 // Radians
constant DAQmx_Val_g =                                                        10186 // g

//*** Values for DAQmx_AI_Voltage_Units ***
//*** Value set VoltageUnits1 ***
//constant DAQmx_Val_Volts =                                                    10348 // Volts
//constant DAQmx_Val_FromCustomScale =                                          10065 // From Custom Scale

//*** Values for DAQmx_AO_Voltage_Units ***
//*** Value set VoltageUnits2 ***
//constant DAQmx_Val_Volts =                                                    10348 // Volts
//constant DAQmx_Val_FromCustomScale =                                          10065 // From Custom Scale

//*** Values for DAQmx_AnlgWin_StartTrig_When ***
//*** Values for DAQmx_AnlgWin_RefTrig_When ***
//*** Value set WindowTriggerCondition1 ***
constant DAQmx_Val_EnteringWin =                                              10163 // Entering Window
constant DAQmx_Val_LeavingWin =                                               10208 // Leaving Window

//*** Values for DAQmx_AnlgWin_PauseTrig_When ***
//*** Value set WindowTriggerCondition2 ***
constant DAQmx_Val_InsideWin =                                                10199 // Inside Window
constant DAQmx_Val_OutsideWin =                                               10251 // Outside Window

//*** Values for DAQmx_Write_RelativeTo ***
//*** Value set WriteRelativeTo ***
//constant DAQmx_Val_FirstSample =                                              10424 // First Sample
constant DAQmx_Val_CurrWritePos =                                             10430 // Current Write Position
