/*
 *  NIDAQmxBaseChannelCreation.cpp
 *  NIDAQmxBaseAccess
 *
 *  Created by John Weeks on 4/1/05.
 *
 */

#include "IncludeXOPStandardHeaders.h"			// Include ANSI headers, Mac headers, IgorXOP.h, XOP.h and XOPSupport.h
#include "NIDAQmxBaseXOPMain.h"
#include "NIDAQmxBaseTaskFuncs.h"
#include "NIDAQmxBase_Utility.h"

#include "NIDAQmxBase.h"
#include "NIDAQmxBaseChannelCreation.h"

int32 DAQmxBaseXOPCreateAIVoltageChan(CreateAIVoltageChanArgs *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	string chanSpec = WM_DAQmx::StringFromHandleAndDispose(p->ChannelSpec);
	string chanName = WM_DAQmx::StringFromHandleAndDispose(p->ChannelName);
	string customScale = WM_DAQmx::StringFromHandleAndDispose(p->customScale);		// actually not used. But if the user passes a string here, we have to dispose of it.
	int32 termConfig = static_cast<int32>(p->terminalConfig);
	int32 units =  static_cast<int32>(p->units);
	
	p->errorCode = DAQmxBaseCreateAIVoltageChan (h, chanSpec.c_str(), chanName.c_str(), termConfig, p->minVal, p->maxVal, units, NULL);
	return 0;
}

int DAQmxBaseXOPCreateAIThrmcplChan(CreateAIThrmcplChanArgs *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	string chanSpec = WM_DAQmx::StringFromHandleAndDispose(p->ChannelSpec);
	string chanName = WM_DAQmx::StringFromHandleAndDispose(p->ChannelName);
	int32 units =  static_cast<int32>(p->units);
	int32 thermocoupleType =  static_cast<int32>(p->thermocoupleType);
	int32 cjcSource =  static_cast<int32>(p->cjcSource);
	string cjcChannel = WM_DAQmx::StringFromHandleAndDispose(p->cjcChannel);
	
	p->errorCode = DAQmxBaseCreateAIThrmcplChan(h, chanSpec.c_str(), chanName.c_str(), p->minVal, p->maxVal, units, 
												thermocoupleType, cjcSource, p->cjcVal, cjcChannel.c_str());
	return 0;
}

int32 DAQmxBaseXOPCreateAOVoltageChan(CreateAOVoltageChanArgs *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	string chanSpec = WM_DAQmx::StringFromHandleAndDispose(p->ChannelSpec);
	string chanName = WM_DAQmx::StringFromHandleAndDispose(p->ChannelName);
	string customScale = WM_DAQmx::StringFromHandleAndDispose(p->customScale);		// actually not used. But if the user passes a string here, we have to dispose of it.
	int32 units =  static_cast<int32>(p->units);
	
	p->errorCode = DAQmxBaseCreateAOVoltageChan (h, chanSpec.c_str(), chanName.c_str(), p->minVal, p->maxVal, units, NULL);

	return 0;
}

int32 DAQmxBaseXOP_CreateDIChan(CreateDChanArgs *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	string chanSpec = WM_DAQmx::StringFromHandleAndDispose(p->lines);
	string chanName = WM_DAQmx::StringFromHandleAndDispose(p->ChannelName);
	int32 grouping =  static_cast<int32>(p->grouping);
	
	p->errorCode = DAQmxBaseCreateDIChan(h, chanSpec.c_str(), chanName.c_str(), grouping);
	return 0;
}

int32 DAQmxBaseXOP_CreateDOChan(CreateDChanArgs *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	string chanSpec = WM_DAQmx::StringFromHandleAndDispose(p->lines);
	string chanName = WM_DAQmx::StringFromHandleAndDispose(p->ChannelName);
	int32 grouping =  static_cast<int32>(p->grouping);
	
	p->errorCode = DAQmxBaseCreateDOChan(h, chanSpec.c_str(), chanName.c_str(), grouping);
	return 0;
}

int32 DAQmxBaseXOP_CreateCIPeriodChan(CreateCIPeriodChanArgs *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	string chanSpec = WM_DAQmx::StringFromHandleAndDispose(p->ChannelSpec);
	string chanName = WM_DAQmx::StringFromHandleAndDispose(p->ChannelName);
	int32 units =  static_cast<int32>(p->units);
	int32 edge = static_cast<int32>(p->edge);
	int32 measMethod = static_cast<int32>(p->measMethod);
	uInt32 divisor = static_cast<uInt32>(p->divisor);
	string customScale = WM_DAQmx::StringFromHandleAndDispose(p->customScale);		// actually not used. But if the user passes a string here, we have to dispose of it.
	
	p->errorCode = DAQmxBaseCreateCIPeriodChan(h, chanSpec.c_str(), chanName.c_str(), p->minVal, p->maxVal, units, edge, measMethod, p->measTime, divisor, NULL);
	return 0;
}

int32 DAQmxBaseXOPCreateCICntEdgeChan(CreateCICountEdgesChanArgs *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	string chanSpec = WM_DAQmx::StringFromHandleAndDispose(p->ChannelSpec);
	string chanName = WM_DAQmx::StringFromHandleAndDispose(p->ChannelName);
	int32 edge = static_cast<int32>(p->edge);
	uInt32 initialCount = static_cast<uInt32>(p->initialCount);
	int32 countDirection = static_cast<int32>(p->countDirection);
	
	p->errorCode = DAQmxBaseCreateCICountEdgesChan(h, chanSpec.c_str(), chanName.c_str(), edge, initialCount, countDirection);
	return 0;
}

int32 DAQmxBaseXOPCreateCIPlsWdthChan(CreateCIPulseWidthChanArgs *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	string chanSpec = WM_DAQmx::StringFromHandleAndDispose(p->ChannelSpec);
	string chanName = WM_DAQmx::StringFromHandleAndDispose(p->ChannelName);
	int32 units =  static_cast<int32>(p->units);
	int32 edge = static_cast<int32>(p->edge);
	string customScale = WM_DAQmx::StringFromHandleAndDispose(p->customScale);		// actually not used. But if the user passes a string here, we have to dispose of it.
	
	p->errorCode = DAQmxBaseCreateCIPulseWidthChan(h, chanSpec.c_str(), chanName.c_str(), p->minVal, p->maxVal, units, edge, NULL);
	return 0;
}

int32 DAQmxBaseXOPCreateCOPlsChanFreq(CreateCOPulseChanArgs *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	string chanSpec = WM_DAQmx::StringFromHandleAndDispose(p->ChannelSpec);
	string chanName = WM_DAQmx::StringFromHandleAndDispose(p->ChannelName);
	int32 units =  static_cast<int32>(p->units);
	int32 idleState =  static_cast<int32>(p->idleState);
	
	p->errorCode = DAQmxBaseCreateCOPulseChanFreq(h, chanSpec.c_str(), chanName.c_str(), units, idleState, p->initialDelay, p->freq, p->dutyCycle);
	return 0;
}
