/*
 *  NIDAQmxBaseChannelCreation.h
 *  NIDAQmxBaseAccess
 *
 *  Created by John Weeks on 4/1/05.
 *
 */

#include "XOPStructureAlignmentTwoByte.h"
 
#include "IncludeXOPStandardHeaders.h"			// Include ANSI headers, Mac headers, IgorXOP.h, XOP.h and XOPSupport.h

typedef struct
{
	Handle			customScale;			// Not used; pass "".
	double			units;					// DAQmx_Val_Volts (10348), only.
	double			maxVal;
	double			minVal;
	double			terminalConfig;			// one of DAQmx_Val_Cfg_Default, DAQmx_Val_RSE, DAQmx_Val_NRSE or DAQmx_Val_Diff (-1, 10083, 10078, 10106)
	Handle			ChannelName;			// assigns a user-defined name to the channel.
	Handle			ChannelSpec;			// /Dev1/ai0, for instance.
	double			taskNumber;
	double			errorCode;
} CreateAIVoltageChanArgs;

int32 DAQmxBaseXOPCreateAIVoltageChan(CreateAIVoltageChanArgs *p);

typedef struct
{
	Handle			cjcChannel;				// channel for cold-junction readings
	double			cjcVal;					// constant cold junction temperature
	double			cjcSource;				// one of DAQmx_Val_BuiltIn, DAQmx_Val_ConstVal, DAQmx_Val_Chan (10200, 10119, 10268)
	double			thermocoupleType;		// see docs for symbolic names; (one of J: 10072, K: 10073, N: 10077, R: 10082, S: 10085, T: 10086, B: 10047, E: 10055)
	double			units;					// DAQmx_Val_DegC, DAQmx_Val_DegF, DAQmx_Val_Kelvins, DAQmx_Val_DegR (10143, 10144, 10145, 10325)
	double			maxVal;
	double			minVal;
	Handle			ChannelName;			// assigns a user-defined name to the channel.
	Handle			ChannelSpec;			// /Dev1/ai0, for instance.
	double			taskNumber;
	double			errorCode;
} CreateAIThrmcplChanArgs;

int DAQmxBaseXOPCreateAIThrmcplChan(CreateAIThrmcplChanArgs *p);

typedef struct
{
	Handle			customScale;			// Not used; pass "".
	double			units;					// DAQmx_Val_Volts (10348), only.
	double			maxVal;
	double			minVal;
	Handle			ChannelName;			// assigns a user-defined name to the channel.
	Handle			ChannelSpec;			// /Dev1/ai0, for instance.
	double			taskNumber;
	double			errorCode;
} CreateAOVoltageChanArgs;

int32 DAQmxBaseXOPCreateAOVoltageChan(CreateAOVoltageChanArgs *p);

typedef struct
{
	double			grouping;				// DAQmx_Val_ChanForAllLines (1), only. (alternative using DAQmx is DAQmx_Val_ChanPerLine, 0).
	Handle			ChannelName;			// assigns a user-defined name to the channel.
	Handle			lines;					// Dev1/port0/0:5, for instance ???
	double			taskNumber;
	double			errorCode;
} CreateDChanArgs;

int32 DAQmxBaseXOP_CreateDIChan(CreateDChanArgs *p);
int32 DAQmxBaseXOP_CreateDOChan(CreateDChanArgs *p);

typedef struct
{
	Handle			customScale;			// Not used; pass "".
	double			divisor;				// always pass 1 for this.
	double			measTime;				// pass 0 only.
	double			measMethod;				// DAQmx_Val_LowFreq1Ctr only (10105).
	double			edge;					// DAQmx_Val_Rising or DAQmx_Val_Falling (10280 or 10171)
	double			units;					// DAQmx_Val_Seconds or DAQmx_Val_Ticks (10364 or 10304)
	double			maxVal;
	double			minVal;
	Handle			ChannelName;			// assigns a user-defined name to the channel.
	Handle			ChannelSpec;			// /Dev1/ai0, for instance.
	double			taskNumber;
	double			errorCode;
} CreateCIPeriodChanArgs;

int32 DAQmxBaseXOP_CreateCIPeriodChan(CreateCIPeriodChanArgs *p);

typedef struct
{
	double			countDirection;			// DAQmx_Val_CountUp or DAQmx_Val_CountDown (10128 or 10124)
	double			initialCount;
	double			edge;					// DAQmx_Val_Rising or DAQmx_Val_Falling (10280 or 10171)
	Handle			ChannelName;			// assigns a user-defined name to the channel.
	Handle			ChannelSpec;			// /Dev1/ai0, for instance.
	double			taskNumber;
	double			errorCode;
} CreateCICountEdgesChanArgs;

int32 DAQmxBaseXOPCreateCICntEdgeChan(CreateCICountEdgesChanArgs *p);

typedef struct
{
	Handle			customScale;			// Not used; pass "".
	double			edge;					// DAQmx_Val_Rising or DAQmx_Val_Falling (10280 or 10171)
	double			units;					// DAQmx_Val_Seconds or DAQmx_Val_Ticks (10364 or 10304)
	double			maxVal;
	double			minVal;
	Handle			ChannelName;			// assigns a user-defined name to the channel.
	Handle			ChannelSpec;			// /Dev1/ai0, for instance.
	double			taskNumber;
	double			errorCode;
} CreateCIPulseWidthChanArgs;

int32 DAQmxBaseXOPCreateCIPlsWdthChan(CreateCIPulseWidthChanArgs *p);

typedef struct
{
	double			dutyCycle;
	double			freq;
	double			initialDelay;
	double			idleState;				// DAQmx_Val_High or DAQmx_Val_Low (10192 or 10214)
	double			units;					// DAQmx_Val_Hz only (10373)
	Handle			ChannelName;			// assigns a user-defined name to the channel.
	Handle			ChannelSpec;			// /Dev1/ai0, for instance.
	double			taskNumber;
	double			errorCode;
} CreateCOPulseChanArgs;

int32 DAQmxBaseXOPCreateCOPlsChanFreq(CreateCOPulseChanArgs *p);

#include "XOPStructureAlignmentReset.h"