/*
 *  NIDAQmxBaseMiscFuncs.cpp
 *  NIDAQmxBaseAccess
 *
 *  Created by John Weeks on 4/1/05.
 *
 */
 
#include <string>
#include <iomanip>
#include <sstream>
//#include <strstream>

#include "IncludeXOPStandardHeaders.h"			// Include ANSI headers, Mac headers, IgorXOP.h, XOP.h and XOPSupport.h
#include "NIDAQmxBaseXOPMain.h"
#include "NIDAQmxBaseTaskFuncs.h"
#include "NIDAQmxBase_Utility.h"
#include "NIDAQmxBaseMiscFuncs.h"

//static char*
//p2cstr(StringPtr aStr)				// Carbon does not include this function.
//{
//	unsigned int numChars;
//	
//	numChars = aStr[0];
//	memmove(aStr, aStr+1, numChars);
//	aStr[numChars] = 0;
//	return (char*)aStr;
//}

static
void DumpWindowList()
{
	WindowRef theWin;
	int i=0;
	
	XOPNotice("Dumping window list:\r\r");
	
	for(theWin= FrontNonFloatingWindow(); theWin!=NULL; theWin= GetNextWindow(theWin))
	{
		std::ostringstream msg;
		Str255 title;
		long wrefcon;
		
		GetWTitle(theWin, title);
		p2cstr(title);
		i++;
		wrefcon = GetWRefCon(theWin);
		msg << i << ")\t" << std::hex << "0x"<< wrefcon << " ";
		if (wrefcon && ((wrefcon & 1) != 1) )
			msg << "*refcon:" << std::hex << "0x" << *(long *)(wrefcon) << " ";
		else
			msg << "Odd refcon ";
		msg << "window kind: " << std::dec << GetWindowKind(theWin) << " ";
		msg << "title: " << title << "\r";
		XOPNotice(msg.str().c_str());
	}
	XOPNotice("END DUMP****\r\r");
}

int DAQmxBaseXOP_ResetDevice(ResetDeviceArgs *p)
{
	p->errorCode = 0.0;
	
//DumpWindowList();

	string devName = WM_DAQmx::StringFromHandleAndDispose(p->deviceName);
	p->errorCode = static_cast<double>(DAQmxBaseResetDevice(devName.c_str()));

//DumpWindowList();

	if (p->errorCode == 0.0)
		EraseTasks();
	
	return 0;
}

int DAQmxBaseXOP_GetErrorInfo(GetErrorInfoArgs *p)
{
	if ( *(p->errorInfo) )
		DisposeHandle(*(p->errorInfo));		// we don't want anything coming in
	
	int32 size = DAQmxBaseGetExtendedErrorInfo(NULL, 0);
	*(p->errorInfo) = NewHandle(size);
	if ( *(p->errorInfo) == 0)
	{
		p->errorCode = NOMEM;
		return 0;
	}
	
	p->errorCode = static_cast<double>(DAQmxBaseGetExtendedErrorInfo(**(p->errorInfo), size));
	return 0;
}

int DAQmxBaseXOP_GetNonNIErrorInfo(GetIgorErrorInfoArgs *p)
{
	char errStr[256];
	int errorNumber = static_cast<int>(p->errorNumber);
	
	if(errorNumber > FIRST_XOP_ERR)
		GetXOPIndString(errStr, static_cast<short>(1100), errorNumber-FIRST_XOP_ERR);
	else
	{
		GetIgorErrorMessage(errorNumber, errStr);
	}
	
	if (*(p->errorInfo) == NULL)
		*(p->errorInfo) = NewHandle(0);
	
	if (*(p->errorInfo))
		PutCStringInHandle(errStr, *(p->errorInfo));
	
	return 0;
}

int DAQmxBaseXOP_CfgInputBuffer(CfgInputBufferArgs *p)
{
	int taskIndex = static_cast<int>(p->taskNumber);
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(taskIndex, h)) != 0.0)
		return 0;
	
	p->errorCode = static_cast<double>(DAQmxBaseStartTask(h));
	return 0;
}
