/*
 *  NIDAQmxBaseReadFunctions.cpp
 *  NIDAQmxBaseAccess
 *
 *  Created by John Weeks on 4/4/05.
 *
 */

#include "IncludeXOPStandardHeaders.h"			// Include ANSI headers, Mac headers, IgorXOP.h, XOP.h and XOPSupport.h
#include "NIDAQmxBaseXOPMain.h"
#include "NIDAQmxBaseTaskFuncs.h"
#include "NIDAQmxBase_Utility.h"

#include "NIDAQmxBase.h"

#include "NIDAQmxBaseReadFunctions.h"

// This function uses the wave directly as the buffer for the read. I believe that this is safe without doing
// anything to lock the wave or responding to the OBJINUSE message because when the function returns, it can't
// be using the wave any more. The acquisition is actually into a buffer created by the driver; this buffer is just
// for copying the data.
int DAQmxBaseXOP_ReadAnalogF64(ReadAnalogDigitalWave *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	waveHndl w = p->dataBuffer;
	if (WaveType(w) != NT_FP64)
	{
		p->errorCode = EXPECT_DOUBLE_WAVE;
		return 0;
	}
	
	int32 numSampsPerChan = static_cast<int32>(p->numSampsPerChan);
	bool32 fillMode = p->fillMode != 0.0;
	double *readArray = reinterpret_cast<double *>(WaveData(w));
	uInt32 arraySizeInSamps = WavePoints(w);
	int32 sampsPerChanRead;

	p->errorCode = DAQmxBaseReadAnalogF64(h, numSampsPerChan, p->timeout, fillMode, readArray, arraySizeInSamps, &sampsPerChanRead, NULL);
	*(p->sampsPerChanRead) = static_cast<double>(sampsPerChanRead);
	if (sampsPerChanRead > 0)
		WaveHandleModified(w);
	
	return 0;
}

int DAQmxBaseXOP_ReadBinaryI16(ReadAnalogDigitalWave *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	waveHndl w = p->dataBuffer;
	if (WaveType(w) != NT_I16)
	{
		p->errorCode = EXPECT_INT16_WAVE;
		return 0;
	}
	
	int32 numSampsPerChan = static_cast<int32>(p->numSampsPerChan);
	bool32 fillMode = p->fillMode != 0.0;
	int16 *readArray = reinterpret_cast<int16 *>(WaveData(w));
	uInt32 arraySizeInSamps = WavePoints(w);
	int32 sampsPerChanRead;

	p->errorCode = DAQmxBaseReadBinaryI16(h, numSampsPerChan, p->timeout, fillMode, readArray, arraySizeInSamps, &sampsPerChanRead, NULL);
	*(p->sampsPerChanRead) = static_cast<double>(sampsPerChanRead);
	if (sampsPerChanRead > 0)
		WaveHandleModified(w);
	
	return 0;
}

int DAQmxBaseXOP_ReadCounterF64(ReadCounterWave *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	waveHndl w = p->dataBuffer;
	if (WaveType(w) != NT_FP64)
	{
		p->errorCode = EXPECT_DOUBLE_WAVE;
		return 0;
	}
	
	int32 numSampsPerChan = static_cast<int32>(p->numSampsPerChan);
	double *readArray = reinterpret_cast<double *>(WaveData(w));
	uInt32 arraySizeInSamps = WavePoints(w);
	int32 sampsPerChanRead;

	p->errorCode = DAQmxBaseReadCounterF64(h, numSampsPerChan, p->timeout, readArray, arraySizeInSamps, &sampsPerChanRead, NULL);
	*(p->sampsPerChanRead) = static_cast<double>(sampsPerChanRead);
	if (sampsPerChanRead > 0)
		WaveHandleModified(w);
	
	return 0;
}

int DAQmxBaseXOP_ReadCounterU32(ReadCounterWave *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	waveHndl w = p->dataBuffer;
	if (WaveType(w) != (NT_I32 | NT_UNSIGNED))
	{
		p->errorCode = EXPECT_UNSIGNED_INT_WAVE;
		return 0;
	}
	
	int32 numSampsPerChan = static_cast<int32>(p->numSampsPerChan);
	uInt32 *readArray = reinterpret_cast<uInt32 *>(WaveData(w));
	uInt32 arraySizeInSamps = WavePoints(w);
	int32 sampsPerChanRead;

	p->errorCode = DAQmxBaseReadCounterU32(h, numSampsPerChan, p->timeout, readArray, arraySizeInSamps, &sampsPerChanRead, NULL);
	*(p->sampsPerChanRead) = static_cast<double>(sampsPerChanRead);
	if (sampsPerChanRead > 0)
		WaveHandleModified(w);
	
	return 0;
}

int DAQmxBaseXOP_ReadDigitalU32(ReadAnalogDigitalWave *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	waveHndl w = p->dataBuffer;
	if (WaveType(w) != (NT_I32 | NT_UNSIGNED))
	{
		p->errorCode = EXPECT_UNSIGNED_INT_WAVE;
		return 0;
	}
	
	int32 numSampsPerChan = static_cast<int32>(p->numSampsPerChan);
	bool32 fillMode = p->fillMode != 0.0;
	uInt32 *readArray = reinterpret_cast<uInt32 *>(WaveData(w));
	uInt32 arraySizeInSamps = WavePoints(w);
	int32 sampsPerChanRead;

	p->errorCode = DAQmxBaseReadDigitalU32(h, numSampsPerChan, p->timeout, fillMode, readArray, arraySizeInSamps, &sampsPerChanRead, NULL);
	*(p->sampsPerChanRead) = static_cast<double>(sampsPerChanRead);
	if (sampsPerChanRead > 0)
		WaveHandleModified(w);
	
	return 0;
}

int DAQmxBaseXOP_ReadDigitalU8(ReadAnalogDigitalWave *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	waveHndl w = p->dataBuffer;
	if (WaveType(w) != (NT_I8 | NT_UNSIGNED))
	{
		p->errorCode = EXPECT_UNSIGNED_BYTE_WAVE;
		return 0;
	}
	
	int32 numSampsPerChan = static_cast<int32>(p->numSampsPerChan);
	bool32 fillMode = p->fillMode != 0.0;
	uInt8 *readArray = reinterpret_cast<uInt8 *>(WaveData(w));
	uInt32 arraySizeInSamps = WavePoints(w);
	int32 sampsPerChanRead;

	p->errorCode = DAQmxBaseReadDigitalU8(h, numSampsPerChan, p->timeout, fillMode, readArray, arraySizeInSamps, &sampsPerChanRead, NULL);
	*(p->sampsPerChanRead) = static_cast<double>(sampsPerChanRead);
	if (sampsPerChanRead > 0)
		WaveHandleModified(w);
	
	return 0;
}

int DAQmxBaseXOP_ReadCntrScalarF64(ReadScalarArgs *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	p->errorCode = DAQmxBaseReadCounterScalarF64(h, p->timeout, p->value, NULL);
	
	return 0;
}

int DAQmxBaseXOP_ReadCntrScalarU32(ReadScalarArgs *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	uInt32 value;
	p->errorCode = DAQmxBaseReadCounterScalarU32(h, p->timeout, &value, NULL);
	*(p->value) = static_cast<double>(value);
	
	return 0;
}

int DAQmxBaseXOP_ReadDigScalarU32(ReadScalarArgs *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	uInt32 value;
	int32 error = DAQmxBaseReadDigitalScalarU32(h, p->timeout, &value, NULL);
	p->errorCode = static_cast<double>(error);
	*(p->value) = static_cast<double>(value);
	
	return 0;
}
