#include <vector>
using std::vector;

#include "IncludeXOPStandardHeaders.h"			// Include ANSI headers, Mac headers, IgorXOP.h, XOP.h and XOPSupport.h
#include "NIDAQmxBaseXOPMain.h"
#include "NIDAQmxBaseTaskFuncs.h"
#include "NIDAQmxBase_Utility.h"

#include "NIDAQmxBase.h"

namespace
{
	vector<TaskHandle> taskHandles;
}	// unnamed namespace

int GetTaskHandle(int tasknumber, TaskHandle &h)
{
	if  (tasknumber >= (int)taskHandles.size() || tasknumber < 0)
	{
		h = NULL;
		return BAD_TASK_NUMBER;
	}
	
	h = taskHandles[tasknumber];
	if (!h)
		return BAD_TASK_NUMBER;
		
	return 0;
}

void EraseTasks(void)
{
	int tasks = taskHandles.size();
	for (int i = 0; i < tasks; ++i)
	{
		if (taskHandles[i])
		{
			DAQmxBaseStopTask(taskHandles[i]);
			DAQmxBaseClearTask(taskHandles[i]);
		}
	}
	WM_DAQmx::ClearVector(taskHandles);
}

int DAQmxBaseXOP_CreateTask(CreateTaskArgs *p)
{
	string tname = WM_DAQmx::StringFromHandleAndDispose(p->taskName);
	TaskHandle h = NULL;
	
	p->errorCode = 0.0;
	
	int32 err = DAQmxBaseCreateTask(tname.c_str(), &h);
	if (err)
	{
		p->errorCode = static_cast<double>(err);
		return 0;
	}
	
	vector<TaskHandle>::iterator i = taskHandles.end();
	if (!taskHandles.empty())
		i = find(taskHandles.begin(), taskHandles.end(), reinterpret_cast<TaskHandle>(0));
	if (i == taskHandles.end())
	{
		// no empty slots
		taskHandles.push_back(h);
		*(p->taskNumber) = taskHandles.size()-1;
	}
	else
	{
		*i = h;
		*(p->taskNumber) =  i-taskHandles.begin();
	}
	
	return 0;
}

int DAQmxBaseXOP_LoadTask(CreateTaskArgs *p)
{
	string tname = WM_DAQmx::StringFromHandleAndDispose(p->taskName);
	TaskHandle h = NULL;
	
	p->errorCode = 0.0;
	
	int32 err = DAQmxBaseLoadTask(tname.c_str(), &h);
	if (err)
	{
		p->errorCode = static_cast<double>(err);
		return 0;
	}
	
	vector<TaskHandle>::iterator i = taskHandles.end();
	if (!taskHandles.empty())
		i = find(taskHandles.begin(), taskHandles.end(), reinterpret_cast<TaskHandle>(0));
	if (i == taskHandles.end())
	{
		// no empty slots
		taskHandles.push_back(h);
		*(p->taskNumber) = taskHandles.size()-1;
	}
	else
	{
		*i = h;
		*(p->taskNumber) =  i-taskHandles.begin();
	}
	
	return 0;
}

int DAQmxBaseXOP_ClearTask(TaskNumberArgs *p)
{
	p->errorCode = 0.0;
	
	int taskIndex = static_cast<int>(p->taskNumber);
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(taskIndex, h)) != 0.0)
		return 0;
	
	int32 err = DAQmxBaseClearTask (h);
	if (err)
	{
		p->errorCode = static_cast<double>(err);
		return 0;
	}
	else
	{
		p->errorCode = 0;
		taskHandles[taskIndex] = NULL;
	}
	
	return 0;
}

int DAQmxBaseXOP_StartTask(TaskNumberArgs *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;

	p->errorCode = static_cast<double>(DAQmxBaseStartTask(h));
	
	return 0;
}

int DAQmxBaseXOP_StopTask(TaskNumberArgs *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;

	p->errorCode = static_cast<double>(DAQmxBaseStopTask(h));
	
	return 0;
}

int DAQmxBaseXOP_IsTaskDone(IsTaskDoneArgs *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	bool32 isDone;
	p->errorCode = static_cast<double>(DAQmxBaseIsTaskDone(h, &isDone));
	*(p->isDone) = isDone ? 1.0 : 0.0;
	
	return 0;
}
