#include "IncludeXOPStandardHeaders.h"			// Include ANSI headers, Mac headers, IgorXOP.h, XOP.h and XOPSupport.h
#include "NIDAQmxBaseXOPMain.h"
#include "NIDAQmxBaseTaskFuncs.h"
#include "NIDAQmxBaseMiscFuncs.h"
#include "NIDAQmxBaseChannelCreation.h"
#include "NIDAQmxBaseReadFunctions.h"
#include "NIDAQmxBase_TimingFuncs.h"
#include "NIDAQmxBase_TriggerFunctions.h"
#include "NIDAQmxBase_WriteFunctions.h"

// ***************************************
// Igor XOP's have a choice of two methods for calling XFUNCs: the message method or the direct method.
// Since it can sometimes be easier to debug problems with calling XFUNCs when you use the message method,
// but performance may be better using the direct method, we provide both. To use the message method,
// uncomment the #define line following.
// ***************************************

//#define USE_MESSAGE_METHOD

enum {
	CREATETASK = 0,
	LOADTASK,					
	CLEARTASK,
	STARTTASK,
	STOPTASK,
	TASKDONE,
	RESETDEVICE,
	ERRORINFO,
	IGORERRORINFO,
	CFGINPUTBUFFER,
	CREATEAIVCHANNEL,
	CREATEAIVTHERMOCHANNEL,
	READANALOGF64,
	READANALOGI16,
	READCOUNTERF64,
	READCOUNTERU32,
	READDIGITALU32,
	READDIGITALU8,
	READCTRSCALARF64,
	READCTRSCALARU32,
	READDIGSCALARU32,
	SAMPLECLKTIMING,
	IMPLICITTIMING,
	CREATEAOVCHANNEL,
	CREATEDICHANNEL,
	CREATEDOCHANNEL,
	CREATECIPERIODCHANNEL,
	CREATECICNTEDGESCHANNEL,
	CREATECIPULSEWIDTHCHANNEL,
	CREATECOPULSECHANNEL,
	DISABLESTARTTRIG,
	DISABLEREFTRIG,
	DIGEDGE_STARTTRIG,
	DIGEDGE_REFTRIG,
	ANALOGEDGE_STARTTRIG,
	ANALOGEDGE_REFTRIG,
	WRITEANALOGF64,
	WRITEDIGITALU8,
	WRITEDIGITALU32,
	WRITESCALARU32,
};

#ifdef USE_MESSAGE_METHOD
static long
RegisterFunction()
{
	return NULL;		// use message method for all functions
}

static int
DoFunction()
{
	int funcIndex;
	int err=-1;

	funcIndex = GetXOPItem(0);		/* which function invoked ? */

	switch (funcIndex) {
		case CREATETASK:
			err = DAQmxBaseXOP_CreateTask(reinterpret_cast<CreateTaskArgs *>(GetXOPItem(1)));
			break;
		case LOADTASK:
			err = DAQmxBaseXOP_LoadTask(reinterpret_cast<CreateTaskArgs *>(GetXOPItem(1)));
			break;
		case CLEARTASK:
			err = DAQmxBaseXOP_ClearTask(reinterpret_cast<TaskNumberArgs *>(GetXOPItem(1)));
			break;
		case STARTTASK:
			err = DAQmxBaseXOP_StartTask(reinterpret_cast<TaskNumberArgs *>(GetXOPItem(1)));
			break;
		case STOPTASK:
			err = DAQmxBaseXOP_StopTask(reinterpret_cast<TaskNumberArgs *>(GetXOPItem(1)));
			break;
		case TASKDONE:
			err = DAQmxBaseXOP_IsTaskDone(reinterpret_cast<IsTaskDoneArgs *>(GetXOPItem(1)));
			break;
		case RESETDEVICE:
			err = DAQmxBaseXOP_ResetDevice(reinterpret_cast<ResetDeviceArgs *>(GetXOPItem(1)));
			break;
		case ERRORINFO:
			err = DAQmxBaseXOP_GetErrorInfo(reinterpret_cast<GetErrorInfoArgs *>(GetXOPItem(1)));
			break;
		case IGORERRORINFO:
			err = DAQmxBaseXOP_GetNonNIErrorInfo(reinterpret_cast<GetIgorErrorInfoArgs *>(GetXOPItem(1)));
			break;
		case CFGINPUTBUFFER:
			err = DAQmxBaseXOP_CfgInputBuffer(reinterpret_cast<CfgInputBufferArgs *>(GetXOPItem(1)));
			break;
		case CREATEAIVCHANNEL:
			err = DAQmxBaseXOPCreateAIVoltageChan(reinterpret_cast<CreateAIVoltageChanArgs *>(GetXOPItem(1)));
			break;
		case CREATEAIVTHERMOCHANNEL:
			err = DAQmxBaseXOPCreateAIThrmcplChan(reinterpret_cast<CreateAIThrmcplChanArgs *>(GetXOPItem(1)));
			break;
		case READANALOGF64:
			err = DAQmxBaseXOP_ReadAnalogF64(reinterpret_cast<ReadAnalogDigitalWave *>(GetXOPItem(1)));
			break;
		case READANALOGI16:
			err = DAQmxBaseXOP_ReadBinaryI16(reinterpret_cast<ReadAnalogDigitalWave *>(GetXOPItem(1)));
			break;
		case READCOUNTERF64:
			err = DAQmxBaseXOP_ReadCounterF64(reinterpret_cast<ReadCounterWave *>(GetXOPItem(1)));
			break;
		case READCOUNTERU32:
			err = DAQmxBaseXOP_ReadCounterU32(reinterpret_cast<ReadCounterWave *>(GetXOPItem(1)));
			break;
		case READDIGITALU32:
			err = DAQmxBaseXOP_ReadDigitalU32(reinterpret_cast<ReadAnalogDigitalWave *>(GetXOPItem(1)));
			break;
		case READDIGITALU8:
			err = DAQmxBaseXOP_ReadDigitalU8(reinterpret_cast<ReadAnalogDigitalWave *>(GetXOPItem(1)));
			break;
		case READCTRSCALARF64:
			err = DAQmxBaseXOP_ReadCntrScalarF64(reinterpret_cast<ReadScalarArgs *>(GetXOPItem(1)));
			break;
		case READCTRSCALARU32:
			err = DAQmxBaseXOP_ReadCntrScalarU32(reinterpret_cast<ReadScalarArgs *>(GetXOPItem(1)));
			break;
		case READDIGSCALARU32:
			err = DAQmxBaseXOP_ReadDigScalarU32(reinterpret_cast<ReadScalarArgs *>(GetXOPItem(1)));
			break;
		case SAMPLECLKTIMING:
			err = DAQmxBaseXOP_CfgSampClkTiming(reinterpret_cast<SampClkTimingArgs *>(GetXOPItem(1)));
			break;
		case IMPLICITTIMING:
			err = DAQmxBasXOP_CfgImplicitTiming(reinterpret_cast<ImplicitTimingArgs *>(GetXOPItem(1)));
			break;
		case CREATEAOVCHANNEL:
			err = DAQmxBaseXOPCreateAOVoltageChan(reinterpret_cast<CreateAOVoltageChanArgs *>(GetXOPItem(1)));
			break;
		case CREATEDICHANNEL:
			err = DAQmxBaseXOP_CreateDIChan(reinterpret_cast<CreateDChanArgs *>(GetXOPItem(1)));
			break;
		case CREATEDOCHANNEL:
			err = DAQmxBaseXOP_CreateDOChan(reinterpret_cast<CreateDChanArgs *>(GetXOPItem(1)));
			break;
		case CREATECIPERIODCHANNEL:
			err = DAQmxBaseXOP_CreateCIPeriodChan(reinterpret_cast<CreateCIPeriodChanArgs *>(GetXOPItem(1)));
			break;
		case CREATECICNTEDGESCHANNEL:
			err = DAQmxBaseXOPCreateCICntEdgeChan(reinterpret_cast<CreateCICountEdgesChanArgs *>(GetXOPItem(1)));
			break;
		case CREATECIPULSEWIDTHCHANNEL:
			err = DAQmxBaseXOPCreateCIPlsWdthChan(reinterpret_cast<CreateCIPulseWidthChanArgs *>(GetXOPItem(1)));
			break;
		case CREATECOPULSECHANNEL:
			err = DAQmxBaseXOPCreateCOPlsChanFreq(reinterpret_cast<CreateCOPulseChanArgs *>(GetXOPItem(1)));
			break;
		case DISABLESTARTTRIG:
			err = DAQmxBaseXOP_DisableStartTrig(reinterpret_cast<TaskNumberOnlyArgs *>(GetXOPItem(1)));
			break;
		case DISABLEREFTRIG:
			err = DAQmxBaseXOP_DisableRefTrig(reinterpret_cast<TaskNumberOnlyArgs *>(GetXOPItem(1)));
			break;
		case DIGEDGE_STARTTRIG:
			err = DAQmxBaseXOP_CfgDigEdgeStrtTrig(reinterpret_cast<DigEdgeStartTrigArgs *>(GetXOPItem(1)));
			break;
		case DIGEDGE_REFTRIG:
			err = DAQmxBaseXOP_CfgDigEdgeRefTrig(reinterpret_cast<DigEdgeRefTrigArgs *>(GetXOPItem(1)));
			break;
		case ANALOGEDGE_STARTTRIG:
			err = DAQmxBaseXOPCfgAnlgEdgeStrtTrig(reinterpret_cast<AnalogStartTrigArgs *>(GetXOPItem(1)));
			break;
		case ANALOGEDGE_REFTRIG:
			err = DAQmxBaseXOP_CfgAnlgEdgeRefTrig(reinterpret_cast<AnalogRefTrigArgs *>(GetXOPItem(1)));
			break;
		case WRITEANALOGF64:
			err = DAQmxBaseXOP_WriteAnalogF64(reinterpret_cast<WriteArgs *>(GetXOPItem(1)));
			break;
		case WRITEDIGITALU8:
			err = DAQmxBaseXOP_WriteDigitalU8(reinterpret_cast<WriteArgs *>(GetXOPItem(1)));
			break;
		case WRITEDIGITALU32:
			err = DAQmxBaseXOP_WriteDigitalU32(reinterpret_cast<WriteArgs *>(GetXOPItem(1)));
			break;
		case WRITESCALARU32:
			err = DAQmxBaseXOP_WriteDigScalarU32(reinterpret_cast<WriteScalarArgs *>(GetXOPItem(1)));
			break;
	}

	return err;
}
#else		// USE_MESSAGE_METHOD

static long RegisterFunction()
{
	int funcIndex;

	funcIndex = GetXOPItem(0);			// Which function invoked ?
	switch (funcIndex) {
		case CREATETASK:
			return reinterpret_cast<long>(&DAQmxBaseXOP_CreateTask);
			break;
		case LOADTASK:
			return reinterpret_cast<long>(&DAQmxBaseXOP_LoadTask);
			break;
		case CLEARTASK:
			return reinterpret_cast<long>(&DAQmxBaseXOP_ClearTask);
			break;
		case STARTTASK:
			return reinterpret_cast<long>(&DAQmxBaseXOP_StartTask);
			break;
		case STOPTASK:
			return reinterpret_cast<long>(&DAQmxBaseXOP_StopTask);
			break;
		case TASKDONE:
			return reinterpret_cast<long>(&DAQmxBaseXOP_IsTaskDone);
			break;
		case RESETDEVICE:
			return reinterpret_cast<long>(&DAQmxBaseXOP_ResetDevice);
			break;
		case ERRORINFO:
			return reinterpret_cast<long>(&DAQmxBaseXOP_GetErrorInfo);
			break;
		case IGORERRORINFO:
			return reinterpret_cast<long>(&DAQmxBaseXOP_GetNonNIErrorInfo);
			break;
		case CFGINPUTBUFFER:
			return reinterpret_cast<long>(&DAQmxBaseXOP_CfgInputBuffer);
			break;
		case CREATEAIVCHANNEL:
			return reinterpret_cast<long>(&DAQmxBaseXOPCreateAIVoltageChan);
			break;
		case CREATEAIVTHERMOCHANNEL:
			return reinterpret_cast<long>(&DAQmxBaseXOPCreateAIThrmcplChan);
			break;
		case READANALOGF64:
			return reinterpret_cast<long>(&DAQmxBaseXOP_ReadAnalogF64);
			break;
		case READANALOGI16:
			return reinterpret_cast<long>(&DAQmxBaseXOP_ReadBinaryI16);
			break;
		case READCOUNTERF64:
			return reinterpret_cast<long>(&DAQmxBaseXOP_ReadCounterF64);
			break;
		case READCOUNTERU32:
			return reinterpret_cast<long>(&DAQmxBaseXOP_ReadCounterU32);
			break;
		case READDIGITALU32:
			return reinterpret_cast<long>(&DAQmxBaseXOP_ReadDigitalU32);
			break;
		case READDIGITALU8:
			return reinterpret_cast<long>(&DAQmxBaseXOP_ReadDigitalU8);
			break;
		case READCTRSCALARF64:
			return reinterpret_cast<long>(&DAQmxBaseXOP_ReadCntrScalarF64);
			break;
		case READCTRSCALARU32:
			return reinterpret_cast<long>(&DAQmxBaseXOP_ReadCntrScalarU32);
			break;
		case READDIGSCALARU32:
			return reinterpret_cast<long>(&DAQmxBaseXOP_ReadDigScalarU32);
			break;
		case SAMPLECLKTIMING:
			return reinterpret_cast<long>(&DAQmxBaseXOP_CfgSampClkTiming);
			break;
		case IMPLICITTIMING:
			return reinterpret_cast<long>(&DAQmxBasXOP_CfgImplicitTiming);
			break;
		case CREATEAOVCHANNEL:
			return reinterpret_cast<long>(&DAQmxBaseXOPCreateAOVoltageChan);
			break;
		case CREATEDICHANNEL:
			return reinterpret_cast<long>(&DAQmxBaseXOP_CreateDIChan);
			break;
		case CREATEDOCHANNEL:
			return reinterpret_cast<long>(&DAQmxBaseXOP_CreateDOChan);
			break;
		case CREATECIPERIODCHANNEL:
			return reinterpret_cast<long>(&DAQmxBaseXOP_CreateCIPeriodChan);
			break;
		case CREATECICNTEDGESCHANNEL:
			return reinterpret_cast<long>(&DAQmxBaseXOPCreateCICntEdgeChan);
			break;
		case CREATECIPULSEWIDTHCHANNEL:
			return reinterpret_cast<long>(&DAQmxBaseXOPCreateCIPlsWdthChan);
			break;
		case CREATECOPULSECHANNEL:
			return reinterpret_cast<long>(&DAQmxBaseXOPCreateCOPlsChanFreq);
			break;
		case DISABLESTARTTRIG:
			return reinterpret_cast<long>(&DAQmxBaseXOP_DisableStartTrig);
			break;
		case DISABLEREFTRIG:
			return reinterpret_cast<long>(&DAQmxBaseXOP_DisableRefTrig);
			break;
		case DIGEDGE_STARTTRIG:
			return reinterpret_cast<long>(&DAQmxBaseXOP_CfgDigEdgeStrtTrig);
			break;
		case DIGEDGE_REFTRIG:
			return reinterpret_cast<long>(&DAQmxBaseXOP_CfgDigEdgeRefTrig);
			break;
		case ANALOGEDGE_STARTTRIG:
			return reinterpret_cast<long>(&DAQmxBaseXOPCfgAnlgEdgeStrtTrig);
			break;
		case ANALOGEDGE_REFTRIG:
			return reinterpret_cast<long>(&DAQmxBaseXOP_CfgAnlgEdgeRefTrig);
			break;
		case WRITEANALOGF64:
			return reinterpret_cast<long>(&DAQmxBaseXOP_WriteAnalogF64);
			break;
		case WRITEDIGITALU8:
			return reinterpret_cast<long>(&DAQmxBaseXOP_WriteDigitalU8);
			break;
		case WRITEDIGITALU32:
			return reinterpret_cast<long>(&DAQmxBaseXOP_WriteDigitalU32);
			break;
		case WRITESCALARU32:
			return reinterpret_cast<long>(&DAQmxBaseXOP_WriteDigScalarU32);
			break;
	}
	return 0;
}
#endif		// USE_MESSAGE_METHOD

/*	XOPEntry()

	This is the entry point from the host application to the XOP for all
	messages after the INIT message.
*/
static void
XOPEntry(void)
{	
	long result = 0;

	switch (GetXOPMessage()) {
		case FUNCADDRS:
			result = RegisterFunction();	// This tells Igor the address of our function.
			break;
		case CLEANUP:	
			EraseTasks();
			result = 0;
			break;
#ifdef USE_MESSAGE_METHOD
		case FUNCTION:								// our external function being invoked?	But, in fact, this xop uses direct calling.
			result = DoFunction();
			break;
#endif
	}
	SetXOPResult(result);
}

/*	main(ioRecHandle)

	This is the initial entry point at which the host application calls XOP.
	The message sent by the host must be INIT.
	main() does any necessary initialization and then sets the XOPEntry field of the
	ioRecHandle to the address to be called for future messages.
*/
HOST_IMPORT int
main(IORecHandle ioRecHandle)
{	
	XOPInit(ioRecHandle);							// Do standard XOP initialization.
	SetXOPEntry(XOPEntry);							// Set entry point for future calls.
	
	if (igorVersion < 504)
	{
		SetXOPResult(IGOR_OBSOLETE);
		return 0;
	}

	SetXOPResult(0L);
}
