#ifndef NIDAQMX_UTILITY_INCLUDED
#define NIDAQMX_UTILITY_INCLUDED

#include <string>
#include <sstream>
#include <iomanip>
#include <vector>
#include <limits>
#include <new>
#include <algorithm>
#include <functional>
#include <list>

using std::string;
using std::vector;
using std::ostringstream;
using std::list;
using std::pair;

namespace WM_DAQmx
{
	// *************************
	// waves
	// *************************
#if 0
	int GetTheWave(string &datafolderPath, string &name, waveHndl *theWave);
#endif
	// *************************
	// miscellaneous utility functions
	// *************************
	
	inline double nan()
	{
		return std::numeric_limits<double>::quiet_NaN();
	}
	
	inline bool iswavechar(char x)
	{
		return x == '_' || isalnum(x);
	}
	
	int isLiberalWaveChar(int currentC);
	
	template<class T>
	void ClearVector(vector<T> &V)
	{
		vector<T> dummy;
		V.swap(dummy);
	}
	
	// *************************
	// string utility functions
	// *************************
	
	bool ciCharEqual(char c1, char c2);
	bool ciStringEqual(const string &s1, const string &s2);
	void PossiblyQuoteString(string &name);
	long trimWSfromString(string &ss);
	void ReplaceStringEOLwCR(string &ss);
	string ReplaceCstrEOLwCR(const char *cc);
	
	// *************************
	// functions to deal with input arguments
	// *************************

	inline string StringFromHandle(Handle h)
	{
		if (h == NULL)
			return "";
		
		return string(*h, 0, GetHandleSize(h));
	}
	
	inline string StringFromHandleAndDispose(Handle h)
	{
		if (h == NULL)
			return "";
		
		string theString = StringFromHandle(h);
		DisposeHandle(h);
		return theString;
	}
}			// namespace WM_DAQmx

#endif		// NIDAQMX_UTILITY_INCLUDED