/*
 *  DAQmxBase_WriteFunctions.cpp
 *  NIDAQmxBaseAccess
 *
 *  Created by John Weeks on 4/5/05.
 *
 */

#include "IncludeXOPStandardHeaders.h"			// Include ANSI headers, Mac headers, IgorXOP.h, XOP.h and XOPSupport.h
#include "NIDAQmxBaseXOPMain.h"
#include "NIDAQmxBaseTaskFuncs.h"
#include "NIDAQmxBase_Utility.h"

#include "NIDAQmxBase.h"

#include "NIDAQmxBase_WriteFunctions.h"

int DAQmxBaseXOP_WriteAnalogF64(WriteArgs *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	waveHndl w = p->dataBuffer;
	if (WaveType(w) != NT_FP64)
	{
		p->errorCode = EXPECT_DOUBLE_WAVE;
		return 0;
	}
	
	int32 numSampsPerChan = static_cast<int32>(p->sampsPerChan);
	bool32 autoStart = p->autoStart != 0.0;
	bool32 dataLayout = p->dataLayout != 0.0;
	double *writeArray = reinterpret_cast<double *>(WaveData(w));
	int32 sampsPerChan;

	p->errorCode = DAQmxBaseWriteAnalogF64(h, numSampsPerChan, autoStart, p->timeout, dataLayout, writeArray, &sampsPerChan, NULL);
	*(p->sampsPerChanWritten) = static_cast<double>(sampsPerChan);
	
	return 0;
}

int DAQmxBaseXOP_WriteDigitalU8(WriteArgs *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	waveHndl w = p->dataBuffer;
	if (WaveType(w) != (NT_I8 | NT_UNSIGNED))
	{
		p->errorCode = EXPECT_UNSIGNED_BYTE_WAVE;
		return 0;
	}
	
	int32 numSampsPerChan = static_cast<int32>(p->sampsPerChan);
	bool32 autoStart = p->autoStart != 0.0;
	bool32 dataLayout = p->dataLayout != 0.0;
	uInt8 *writeArray = reinterpret_cast<uInt8 *>(WaveData(w));
	int32 sampsPerChan;

	p->errorCode = DAQmxBaseWriteDigitalU8(h, numSampsPerChan, autoStart, p->timeout, dataLayout, writeArray, &sampsPerChan, NULL);
	*(p->sampsPerChanWritten) = static_cast<double>(sampsPerChan);
	
	return 0;
}

int DAQmxBaseXOP_WriteDigitalU32(WriteArgs *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	waveHndl w = p->dataBuffer;
	if (WaveType(w) != (NT_I32 | NT_UNSIGNED))
	{
		p->errorCode = EXPECT_DOUBLE_WAVE;
		return 0;
	}
	
	int32 numSampsPerChan = static_cast<int32>(p->sampsPerChan);
	bool32 autoStart = p->autoStart != 0.0;
	bool32 dataLayout = p->dataLayout != 0.0;
	uInt32 *writeArray = reinterpret_cast<uInt32 *>(WaveData(w));
	int32 sampsPerChan;

	p->errorCode = DAQmxBaseWriteDigitalU32(h, numSampsPerChan, autoStart, p->timeout, dataLayout, writeArray, &sampsPerChan, NULL);
	*(p->sampsPerChanWritten) = static_cast<double>(sampsPerChan);
	
	return 0;
}

int DAQmxBaseXOP_WriteDigScalarU32(WriteScalarArgs *p)
{
	p->errorCode = 0.0;
	
	TaskHandle h;
	if ((p->errorCode = GetTaskHandle(static_cast<int>(p->taskNumber), h)) != 0.0)
		return 0;
	
	bool32 autoStart = p->autoStart != 0.0;
	uInt32 value = static_cast<uInt32>(p->value);

	p->errorCode = DAQmxBaseWriteDigitalScalarU32(h, autoStart, p->timeout, value, NULL);
	
	return 0;
}
